@@ -42,6 +42,7 @@ def __handle_hist_data_ex_ret(code_list=['00700'],
                               data_type=None):
     # 获取历史历史K线数据
     try:
+        update_url = lambda url: url.replace("__kaisarooturl__", KAISA_ROOT_URL)
         if data_type is None or data_type not in ORI_DATA_TYPE_LIST:
             return DATETYPE_ERROR
 
@@ -93,7 +94,8 @@ def __handle_hist_data_ex_ret(code_list=['00700'],
                 "pageNum": page,
                 "pageSize": 1000
             }
-            URL = HK_STOCK_KLINE_POST_URL
+
+            URL = update_url(HK_STOCK_KLINE_POST_URL)   # HK_STOCK_KLINE_POST_URL
             _pages_ = handle_hist_data_req_pages(body=body, URL=URL)
             ori_cols = KLINE_ORI_COLS
             res_cols = KLINE_RES_COLS
@@ -108,15 +110,19 @@ def __handle_hist_data_ex_ret(code_list=['00700'],
                 "pageSize": 1000
             }
             if data_type == TICKER:
-                URL = HK_STOCK_TICK_POST_URL
+                URL = update_url(HK_STOCK_TICK_POST_URL)  # HK_STOCK_TICK_POST_URL
                 ori_cols = TICKER_ORI_COLS
                 res_cols = TICKER_RES_COLS
             elif data_type == BROKER:
-                URL = HK_STOCK_BROKER_URL
+                URL = update_url(HK_STOCK_BROKER_URL)
                 ori_cols = BROKER_ORI_COLS
                 res_cols = BROKER_RES_COLS
+                print('url:{}'.format(URL))
+                print('ori_cols:{}'.format(ori_cols))
+                print('res_cols:{}'.format(res_cols))
+
             elif data_type == LEVEL10:
-                URL = HK_STOCK_LEVEL2_10_ORDER_URL
+                URL = update_url(HK_STOCK_LEVEL2_10_ORDER_URL)
                 ori_cols = LEVEL10_ORI_COLS
                 res_cols = LEVEL10_RES_COLS
             else:
